import io
import tornado.web
from tornado.ioloop import IOLoop, PeriodicCallback
from tornado.websocket import WebSocketHandler
from picamera import PiCamera

camera = PiCamera()
camera.rotation = 180
camera.resolution = (300, 300)

class TPiWebSocket(tornado.websocket.WebSocketHandler):

    def open(self):
        print("[WS]: opened")
        self.camera_loop = PeriodicCallback(self.loop, 100)
        self.camera_loop.start()

    def on_message(self, message):
        print(f'[WS]: received message: {message}')

    def on_close(self):
        print("[WS]: closed")

    def check_origin(self, origin):
        return True

    def loop(self):
        sio = io.BytesIO()
        camera.capture(sio, "jpeg", use_video_port=True)

        try:
            self.write_message(sio.getvalue(), binary=True)
        except tornado.websocket.WebSocketClosedError:
            self.camera_loop.stop() 


def main():
    handlers = [(r"/", TPiWebSocket)]
    app = tornado.web.Application(handlers)
    app.listen(8080)
    print('[Server]: Running ...')
    IOLoop.current().start()



from setuptools import setup

from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name = 'teachable_pi_websocket',
    packages = ['teachable_pi_websocket'],
    version = '0.0.1',
    license = 'MIT',
    author = 'Lukas Kirner',
    author_email = 'lukas.kirner@gmail.com',
    long_description = long_description,
    long_description_content_type = 'text/markdown',
    url = 'https://github.com/lukaskirner/teachable-pi-websocket',
    download_url = 'https://github.com/user/reponame/archive/v_01.tar.gz',
    keywords = ['Teachable Machine', 'picamera', 'Raspberry Pi'],
    install_requires=[
        'tornado',
        'picamera',
    ],
    entry_points = {
        'console_scripts': ['teachable-pi-websocket=teachable_pi_websocket.command_line:main'],
    },
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
)